@@ -36,6 +36,13 @@ static const int BIO_CTRL_INFO;
 static const int BIO_CTRL_GET;
 static const int BIO_CTRL_PENDING;
 static const int BIO_CTRL_WPENDING;
+static const int BIO_CTRL_DGRAM_SET_CONNECTED;
+static const int BIO_CTRL_DGRAM_SET_RECV_TIMEOUT;
+static const int BIO_CTRL_DGRAM_GET_RECV_TIMEOUT;
+static const int BIO_CTRL_DGRAM_SET_SEND_TIMEOUT;
+static const int BIO_CTRL_DGRAM_GET_SEND_TIMEOUT;
+static const int BIO_CTRL_DGRAM_GET_RECV_TIMER_EXP;
+static const int BIO_CTRL_DGRAM_GET_SEND_TIMER_EXP;
 static const int BIO_C_FILE_SEEK;
 static const int BIO_C_FILE_TELL;
 static const int BIO_TYPE_NONE;
@@ -68,6 +75,7 @@ BIO *BIO_new_file(const char *, const char *);
 BIO *BIO_new_fp(FILE *, int);
 BIO *BIO_new_fd(int, int);
 BIO *BIO_new_socket(int, int);
+BIO *BIO_new_dgram(int, int);
 long BIO_ctrl(BIO *, int, long, void *);
 long BIO_callback_ctrl(
     BIO *,
@@ -82,9 +90,6 @@ int BIO_gets(BIO *, char *, int);
 int BIO_write(BIO *, const void *, int);
 int BIO_puts(BIO *, const char *);
 int BIO_method_type(const BIO *);
-"""
-
-MACROS = """
 /* Added in 1.1.0 */
 int BIO_up_ref(BIO *);
 
@@ -94,12 +99,13 @@ BIO_METHOD *BIO_s_mem(void);
 BIO_METHOD *BIO_s_file(void);
 BIO_METHOD *BIO_s_fd(void);
 BIO_METHOD *BIO_s_socket(void);
+BIO_METHOD *BIO_s_datagram(void);
 BIO_METHOD *BIO_s_null(void);
 BIO_METHOD *BIO_f_null(void);
 BIO_METHOD *BIO_f_buffer(void);
 /* BIO_new_mem_buf became const void * in 1.0.2g */
 BIO *BIO_new_mem_buf(void *, int);
-long BIO_set_fd(BIO *, long, int);
+long BIO_set_fd(BIO *, int, long);
 long BIO_get_fd(BIO *, char *);
 long BIO_set_mem_eof_return(BIO *, int);
 long BIO_get_mem_data(BIO *, char **);
